==> tempest2-testing-docker-2024.04.02.213403-4170185-javadoc.jar: tempest-testing-internal/app.cash.tempest.testing.internal/index.md <==
//[tempest-testing-internal](../../index.md)/[app.cash.tempest.testing.internal](index.md)

# Package-level declarations

## Types

| Name | Summary |
|---|---|
| [DefaultTestDynamoDbClient](-default-test-dynamo-db-client/index.md) | [jvm]<br>class [DefaultTestDynamoDbClient](-default-test-dynamo-db-client/index.md)(val tables: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;TestTable&gt;, port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)) : AbstractIdleService, TestDynamoDbClient |
| [Tag](-tag/index.md) | [jvm]<br>typealias [Tag](-tag/index.md) = [Pair](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt; |
| [TestDynamoDbService](-test-dynamo-db-service/index.md) | [jvm]<br>class [TestDynamoDbService](-test-dynamo-db-service/index.md) : AbstractIdleService<br>This Guava service spins up a DynamoDB server in tests. It shares the server across tests and keeps the server running until the process exits. |

## Functions

| Name | Summary |
|---|---|
| [buildDynamoDb](build-dynamo-db.md) | [jvm]<br>fun [buildDynamoDb](build-dynamo-db.md)(host: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [AmazonDynamoDB](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDB.html) |
| [buildDynamoDbStreams](build-dynamo-db-streams.md) | [jvm]<br>fun [buildDynamoDbStreams](build-dynamo-db-streams.md)(host: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [AmazonDynamoDBStreams](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDBStreams.html) |
| [createTable](create-table.md) | [jvm]<br>fun [AmazonDynamoDB](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDB.html).[createTable](create-table.md)(table: TestTable) |
| [debug](debug.md) | [jvm]<br>fun KLogger.[debug](debug.md)(vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[debug](debug.md)(th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
| [error](error.md) | [jvm]<br>fun KLogger.[error](error.md)(vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[error](error.md)(th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
| [getLogger](get-logger.md) | [jvm]<br>inline fun &lt;[T](get-logger.md)&gt; [getLogger](get-logger.md)(): KLogger |
| [hostName](host-name.md) | [jvm]<br>fun [hostName](host-name.md)(port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [info](info.md) | [jvm]<br>fun KLogger.[info](info.md)(vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[info](info.md)(th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
| [isServerListening](is-server-listening.md) | [jvm]<br>fun [isServerListening](is-server-listening.md)(host: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [log](log.md) | [jvm]<br>fun KLogger.[log](log.md)(level: Level, vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[log](log.md)(level: Level, th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
| [pickRandomPort](pick-random-port.md) | [jvm]<br>fun [pickRandomPort](pick-random-port.md)(): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [warn](warn.md) | [jvm]<br>fun KLogger.[warn](warn.md)(vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[warn](warn.md)(th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |

==> tempest2-testing-docker-2024.11.05.180436-5071a87-javadoc.jar: tempest-testing-internal/app.cash.tempest.testing.internal/index.md <==
//[tempest-testing-internal](../../index.md)/[app.cash.tempest.testing.internal](index.md)

# Package-level declarations

## Types

| Name | Summary |
|---|---|
| [DefaultTestDynamoDbClient](-default-test-dynamo-db-client/index.md) | [jvm]<br>class [DefaultTestDynamoDbClient](-default-test-dynamo-db-client/index.md)(val tables: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;TestTable&gt;, port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)) : AbstractIdleService, TestDynamoDbClient |
| [Tag](-tag/index.md) | [jvm]<br>typealias [Tag](-tag/index.md) = [Pair](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html)&lt;[String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt; |
| [TestDynamoDbService](-test-dynamo-db-service/index.md) | [jvm]<br>class [TestDynamoDbService](-test-dynamo-db-service/index.md) : AbstractIdleService<br>This Guava service spins up a DynamoDB server in tests. It shares the server across tests and keeps the server running until the process exits. |

## Functions

| Name | Summary |
|---|---|
| [allocateRandomPort](allocate-random-port.md) | [jvm]<br>fun [allocateRandomPort](allocate-random-port.md)(): [ServerSocket](https://docs.oracle.com/en/java/javase/11/docs/api/java.base/java/net/ServerSocket.html) |
| [buildDynamoDb](build-dynamo-db.md) | [jvm]<br>fun [buildDynamoDb](build-dynamo-db.md)(host: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [AmazonDynamoDB](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDB.html) |
| [buildDynamoDbStreams](build-dynamo-db-streams.md) | [jvm]<br>fun [buildDynamoDbStreams](build-dynamo-db-streams.md)(host: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [AmazonDynamoDBStreams](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDBStreams.html) |
| [createTable](create-table.md) | [jvm]<br>fun [AmazonDynamoDB](https://docs.aws.amazon.com/AWSJavaSDK/latest/javadoc/com/amazonaws/services/dynamodbv2/AmazonDynamoDB.html).[createTable](create-table.md)(table: TestTable) |
| [debug](debug.md) | [jvm]<br>fun KLogger.[debug](debug.md)(vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[debug](debug.md)(th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
| [error](error.md) | [jvm]<br>fun KLogger.[error](error.md)(vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[error](error.md)(th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
| [getLogger](get-logger.md) | [jvm]<br>inline fun &lt;[T](get-logger.md)&gt; [getLogger](get-logger.md)(): KLogger |
| [hostName](host-name.md) | [jvm]<br>fun [hostName](host-name.md)(port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [info](info.md) | [jvm]<br>fun KLogger.[info](info.md)(vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[info](info.md)(th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
| [isServerListening](is-server-listening.md) | [jvm]<br>fun [isServerListening](is-server-listening.md)(host: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html), port: [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [log](log.md) | [jvm]<br>fun KLogger.[log](log.md)(level: Level, vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[log](log.md)(level: Level, th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
| [pickRandomPort](pick-random-port.md) | [jvm]<br>fun [pickRandomPort](pick-random-port.md)(): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [warn](warn.md) | [jvm]<br>fun KLogger.[warn](warn.md)(vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)<br>fun KLogger.[warn](warn.md)(th: [Throwable](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-throwable/index.html), vararg tags: [Tag](-tag/index.md), message: () -&gt; [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |
